# Initiating Integration API Runs with Python
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/initiating-integration-api-runs-with-python#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/initiating-integration-api-runs-with-python#prerequisites)
  * [Initial Script Setup](https://help.sap.com/docs/leanix/ea/initiating-integration-api-runs-with-python#initial-script-setup)
  * [Adjust Connector Variables](https://help.sap.com/docs/leanix/ea/initiating-integration-api-runs-with-python#adjust-connector-variables)
  * [Adapt for Inbound](https://help.sap.com/docs/leanix/ea/initiating-integration-api-runs-with-python#adapt-for-inbound)
